# Styleout
# Copyright 2010 MyFreeWeb <me@myfreeweb.ru>

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import warnings
import yaml

try: import cssmin
except: cssmin = None
try: import cssprefixer
except: cssprefixer = None
try: import clevercss
except: clevercss = None

wstr = '%s is not installed - cannot %s the CSS'
sk_wstr = '%s is not installed - skipping %s'
gext = lambda a: a.split('.')[-1]
cli_compilers = {
    'less': 'lessc %s %s',
    'sass': 'sass %s:%s',
    'scss': 'sass %s:%s',
}

class Config(object):
    
    def __init__(self, text):
        self.cnf = yaml.load(text)

    def process(self):
        for sheet in self.cnf:
            result = ''
            sht = self.cnf[sheet]
            for fl in sht['files']:
                ext = gext(fl)
                src = open(fl, 'r').read()
                if ext == 'css':
                    result += src
                elif ext == 'clevercss':
                    if clevercss != None:
                        result += clevercss.convert(src)
                    else:
                        warnings.warn(sk_wstr % ('CleverCSS', fl))
                else:
                    for c in cli_compilers:
                        if ext == c:
                            tmpf = '.tempfile'
                            os.system(cli_compilers[c] % (fl, tmpf))
                            result += open(tmpf, 'r').read()
                            os.remove(tmpf)
                
            if sht['prefix']:
                if cssprefixer != None: result = cssprefixer.process(result)
                else:
                    warnings.warn(wstr % ('CSSPrefixer', 'prefix'))
            if sht['minify']:
                if cssmin != None: result = cssmin.cssmin(result)
                else:
                    warnings.warn(wstr % ('cssmin', 'minify'))
            open(sheet, 'w').write(result)
            print 'Compiled ' + sheet

        return True
